@@ -603,7 +603,7 @@ Interfaces = Literal["camera", "ptz", "prebuffer", "audioDetector", "motionDetec
 
 class CameraDelegate(metaclass=ABCMeta):
     @abstractmethod
-    async def snapshot(self) -> bytes: ...
+    async def snapshot(self) -> Optional[bytes]: ...
 
 
 CameraDelegateMethodNames = Literal["reboot", "snapshot"]
@@ -803,7 +803,7 @@ class CameraDevice(Protocol):
 
     async def connect(self) -> None: ...
     async def disconnect(self) -> None: ...
-    async def snapshot(self, force_new: Optional[bool] = None) -> bytes: ...
+    async def snapshot(self, force_new: Optional[bool] = None) -> Optional[bytes]: ...
     async def get_frames(self, prebuffer_duration: int = 0) -> AsyncGenerator[VideoFrame, None]: ...
     async def get_motion_frames(self) -> AsyncGenerator[MotionFrame, None]: ...
     async def get_ffmpeg_path(self) -> str: ...
